@@ -8,7 +8,7 @@
 	
 	$view_id = $_SESSION['view_id'];
 
-	include ("../connect/db_connection_2.php");
+	include ("../connect/db_connect_2.php");
 
 	$categories_name = $_POST['categories_name'];
 	$categories_name = str_replace("&", "and", $categories_name);
@@ -16,12 +16,12 @@
 	$today = date("Y-m-d H:i:s");
 
 	$query = "INSERT INTO zen_categories (date_added) VALUES ('$today')";
-	$result = mysql_query($query, $zen_link);
+	$cnt = $zen_dbh->exec($query);
 	
-	$categories_id = mysql_insert_id();
+	$categories_id = $zen_dbh->lastInsertId();
 	
 	$query = "INSERT INTO zen_categories_description (categories_id, categories_name, categories_description) VALUES ('$categories_id', '$categories_name', '$categories_description')";
-	$result = mysql_query($query, $zen_link);
+	$cnt = $zen_dbh->exec($query);
 	
 	// And create actual folders.
 	$cat_folder = str_replace(" ", "_", $categories_name);
