@@ -10,8 +10,8 @@
 	include ("check_session.php");
 	
 	$query = "SELECT head_name FROM " . BWB_TABLE_PREFIX . "head ORDER BY head_name DESC";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$head_name = $row["head_name"];
 	
 	$today = date("Y-m-d H:i:s");
@@ -24,7 +24,7 @@
 		$index = $index + 1;
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "head SET head_name = 'head" . $index . "', revised='$today'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	header("Location: manage_head.php");
 ?>
\ No newline at end of file
