@@ -15,21 +15,21 @@
 	$_SESSION['last_user_table'] = $user_table;
 	
 	$query = "ALTER TABLE `" . $user_table . "` ADD `email` VARCHAR( 256 ) NULL;";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	$query = "ALTER TABLE `" . $user_table . "`ADD `UserID` VARCHAR( 64 ) NULL;";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	$query = "ALTER TABLE `" . $user_table . "` ADD `password` VARCHAR( 256 ) NULL;";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	$query = "ALTER TABLE `" . $user_table . "` ADD `AccessLevel` VARCHAR( 64 ) NULL;";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	$query = "ALTER TABLE `" . $user_table . "` ADD `Active` tinyint(4) NOT NULL default '0';";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	$query = "ALTER TABLE `" . $user_table . "` ADD `Session` VARCHAR( 32 ) NULL;";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	$query = "ALTER TABLE `" . $user_table . "` ADD `IP` VARCHAR( 16 ) NULL;";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	$query = "ALTER TABLE `" . $user_table . "` ADD `welcome_message_page` VARCHAR( 255 ) NULL;";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	echo "Fields added";
 
