@@ -23,7 +23,7 @@
 		echo "No action given.  Don't know what to do.";
 		exit;
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	echo "Query complete.";
 	
 ?>
