@@ -7,12 +7,12 @@
 	$password = $_POST['password'];
 	$view_id = $_POST['selectAccessLevel'];
 
-	include "../connect/db_connection.php";
+	include "../connect/db_connect.php";
 	
 	//First check to see if user exists.
 	$query = "SELECT * FROM users WHERE `UserID` = '$user_name'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $zen_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$tmp_user_name = $row["UserID"];
 	if ($tmp_user_name)
 	{
@@ -20,14 +20,15 @@
 		exit;
 	}
 	// Add user to database.
+	//$query = "INSERT INTO users SET UserID='$user_name', Password='$password', view_id='$view_id'";
 	if ($view_id == 1)
 		$access_level = "admin";
 	elseif ($view_id == 2)
 		$access_level = "user";
 	elseif ($view_id == 3)
 		$access_level = "reseller";
-	$query = "INSERT INTO users SET UserID='$user_name', `password`='$password', AccessLevel='$access_level'";
-	$result = mysql_query($query, $bwb_link);
+	$query = "INSERT INTO users SET UserID='$user_name', Password='$password', AccessLevel='$access_level'";
+	$cnt = $zen_dbh->exec($query);
 	
 	header("Location: users.php");
 	
