@@ -16,7 +16,7 @@
 	$_SESSION['last_user_table'] = $user_table;
 	
 	$query = "UPDATE `" . $user_table . "` SET `welcome_message_page`='" . $welcome_message_page . "'";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	echo "Welcome message page added";
 
