@@ -44,8 +44,9 @@
 	
 	$css_string = "";
 	$query_build_string = "SELECT * FROM `" . BWB_TABLE_PREFIX . $site_css_table . "`";
-	$result_build_string = mysql_query($query_build_string);
-	while ($row_bs = mysql_fetch_array($result_build_string))
+	$result_build_string = $bwb_dbh->query($query_build_string);
+	
+	while ($row_bs = $result_build_string->fetch(PDO::FETCH_ASSOC))
 	{
 		$class = $row_bs["class"];
 		if (!is_null($row_bs["use_table_data"])) $use_table_data = $row_bs["use_table_data"];
@@ -541,8 +542,8 @@
 	if ($site_css_table == "site_css")
 	{
 		$query_build_string = "SELECT * FROM `" . BWB_TABLE_PREFIX . $custom_site_css_table . "`";	
-		$result_build_string = mysql_query($query_build_string);
-		$row_bs = mysql_fetch_array($result_build_string);
+		$result_build_string = $bwb_dbh->query($query_build_string);
+		$row_bs = $result_build_string->fetch(PDO::FETCH_ASSOC);
 		if ($row_bs["custom_css"])
 			$css_string .= $row_bs["custom_css"];
 	}
