@@ -13,12 +13,12 @@
 	$userid = $_SESSION['userid'];
 	$curr_session = md5(session_id());
 	
-	include ("../connect/db_connection.php");
+	include ("../connect/db_connect.php");
 	include ("../connect/config.php");
 	
 	$query = "SELECT `Session`, `IP`, `AccessLevel` FROM `" . BWB_TABLE_PREFIX . "users` WHERE `UserID`='$userid'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	
 	$session = $row['Session'];
 	$ip = $row['IP'];
