@@ -11,20 +11,20 @@
 	$manufacturers_name = $_GET['manufacturers_name'];
 	$image_folder = $_GET['image_folder'];
 
-	include "../connect/db_connection_2.php";
+	include "../connect/db_connect_2.php";
 	
 	// Now go ahead and delete page record from table.
 	$query = "DELETE FROM zen_manufacturers WHERE manufacturers_name = '$manufacturers_name'";
-	$result = mysql_query($query, $zen_link);
+	$cnt = $zen_dbh->exec($query);
 	
 	// And delete actual folder.
 	// For each category, rename the artist image folder if it exists.
 	$query = "SELECT * FROM zen_categories_description";
-	$result = mysql_query($query, $zen_link);
-	$num_results = mysql_num_rows($result);
+	$result = $zen_dbh->query($query);
+	$num_results = $result->rowCount();
 	for ($i = 0; $i < $num_results; $i++)
 	{
-		$row = mysql_fetch_array($result);
+		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$categories_name = $row["categories_name"];
 		$cat_folder = str_replace(" ", "_", $categories_name);
 		$cat_folder = strtolower($cat_folder);
