@@ -10,20 +10,20 @@
 	
 	$categories_name = $_GET['categories_name'];
 
-	include "../connect/db_connection_2.php";
+	include "../connect/db_connect_2.php";
 	
 	// Get category ID and delete.
 	$query = "SELECT * FROM zen_categories_description WHERE categories_name = '$categories_name'";
-	$result = mysql_query($query, $zen_link);
-	$row = mysql_fetch_array($result);
+	$result = $zen_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$categories_id = $row["categories_id"];
 	
 	// Now go ahead and delete records from tables.
 	$query = "DELETE FROM zen_categories WHERE categories_id = '$categories_id'";
-	$result = mysql_query($query, $zen_link);
+	$cnt = $zen_dbh->exec($query);
 	
 	$query = "DELETE FROM zen_categories_description WHERE categories_name = '$categories_name'";
-	$result = mysql_query($query, $zen_link);
+	$cnt = $zen_dbh->exec($query);
 	
 	// And delete actual folder.
 	$document_root = $_SERVER['DOCUMENT_ROOT'];
