@@ -15,8 +15,8 @@
 	$today = addslashes(date("m/d/Y  H:m:s"));
 		
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "head";
-	$result = mysql_query($query, $bwb_link);
-	while ($row = mysql_fetch_array($result))
+	$result = $bwb_dbh->query($query);
+	while ($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
 		$id = $row["id"];
 		$head_content = $row["head_content"];
@@ -25,7 +25,7 @@
 		{
 			$head_content = str_replace("<link rel='shortcut icon' href='../" . BWB_IMAGE_DIR . "/favicon.ico' type='image/x-icon'>", "", $head_content);
 			$query2 = "UPDATE " . BWB_TABLE_PREFIX . "head SET head_content = '" . $head_content . "', revised='" . $today . "' WHERE id = " . $id;
-			$result2 = mysql_query($query2, $bwb_link);
+			$cnt = $bwb_dbh->exec($query2);
 		}
 	}
 	
