@@ -12,7 +12,7 @@
 	
 	// Now go ahead and delete page record from table.
 	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_bkup WHERE ID = '$ID'";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	header("Location: restore_page_select.php");
 	
