@@ -15,11 +15,11 @@
 	
 	// Delete head.
 	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "head WHERE head_name = '". $head_name . "'";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	// Delete draft.
 	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$head_name' AND `source`=2";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	header("Location: manage_head.php");
 ?>
\ No newline at end of file
