@@ -17,7 +17,7 @@
 	$menu_items_table = "menu"  . $suffix . "_items";
 		
 	$query = "DELETE FROM `" . BWB_TABLE_PREFIX . $menu_items_table . "` WHERE `ID` = '$ID'";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	header("Location: populate_menu_items.php?menu=$menu");
 	
