@@ -26,11 +26,11 @@
 //	include "../connect/db_connection.php";
 	
 	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
-	$result = mysql_query($query, $bwb_link);
-	$num_results = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$num_results = $result->rowCount();
 	for ($i == 1; $i < $num_results; $i++)
 	{
-		$row = mysql_fetch_array($result);
+		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$page_name = $row["page_name"];
 		echo "<option value='$page_name'>$page_name</option>";
     }
