@@ -14,10 +14,10 @@
 	$area_name = $_REQUEST['area_name'];
 	
 	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '". $area_name . "'";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name = '". $area_name . "' AND `source`=1";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	header("Location: manage_special.php");
 ?>
\ No newline at end of file
