@@ -26,7 +26,7 @@
 	else
 		$query = "DELETE FROM " . $table . " WHERE UserID = '$user_name'";
 		
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	if ((!$table) || ($table == ""))
 		header("Location: users.php");
