@@ -5,11 +5,11 @@
 
 	$user_name = $_GET['user_name'];
 
-	include "../connect/db_connection.php";
+	include "../connect/db_connect.php";
 	
 	// Go ahead and delete page record from table.
 	$query = "DELETE FROM users WHERE UserID = '$user_name'";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $zen_dbh->exec($query);
 	
 	header("Location: users.php");
 	
