@@ -12,7 +12,7 @@
 	$old_categories_name = $_POST['category_edit_list'];
 	$categories_description = $_POST['categories_description_update'];
 
-	include "../connect/db_connection_2.php";
+	include "../connect/db_connect_2.php";
 	
 	//First get old and new folder names.
 	$old_categories_folder = $old_categories_name;
@@ -22,7 +22,7 @@
 	
 	// Now go ahead and update category record from table.
 	$query = "UPDATE `zen_categories_description` SET `categories_name`='$new_categories_name', `categories_description`='$categories_description' WHERE `categories_name` = '$old_categories_name'";
-	$result = mysql_query($query, $zen_link);
+	$cnt = $zen_dbh->exec($query);
 	
 	// And rename actual folder.
 	$document_root = $_SERVER['DOCUMENT_ROOT'];
