@@ -77,8 +77,8 @@ Select a menu to add items to:
     <option value="-not selected-">-not selected-</option>
 <?php
 	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menus`";
-	$result = mysql_query($query, $bwb_link);
-	while($row = mysql_fetch_array($result))
+	$result = $bwb_dbh->query($query);
+	while($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
 		$menu_name = $row['menu_name'];
 		$description = $row['description'];
@@ -117,16 +117,16 @@ Select a menu to add items to:
 	$menu_css_table = $menu . "_css" ;
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = 'ul.nav" . $suffix . ", .nav" . $suffix . " ul'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["display"] == "inline")
 		$orientation = "horizontal";
 	else
 		$orientation = "vertical";
 		
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = 'ul.nav" . $suffix . ">li'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["display"] == "table-cell")
 		$orientation = "horizontal";
 	else
@@ -160,8 +160,8 @@ Select a menu to add items to:
 		$top_level_padding_left = 8;
 		
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = 'ul.nav" . $suffix . " li>ul'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (!is_null($row["margin_top"]))
 		$sub_level_offset_top = $row["margin_top"];
 	elseif ($orientation == "horizontal")
@@ -197,8 +197,8 @@ Select a menu to add items to:
 		$sub_level_collapse = true;
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.nav" . $suffix . " ul li a'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (!is_null($row["padding_top"]))
 		$sub_level_padding_top = $row["padding_top"];
 	else
@@ -217,8 +217,8 @@ Select a menu to add items to:
 		$sub_level_padding_left = 10;
 		
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = 'ul.nav" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (($row["table_layout"] == "fixed") && ($orientation == "horizontal"))
 		$orientation = "horizontal_variable_width";
 	elseif ($orientation == "horizontal")
@@ -231,8 +231,8 @@ Select a menu to add items to:
 	$text_align = $row["align"];
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.menu_div" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (!is_null($row["position_top"]))
 		$menu_top = $row["position_top"];
 	else
@@ -248,8 +248,8 @@ Select a menu to add items to:
 		
 	/////////////////////////////////////////
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menus WHERE menu_name = '" . $menu . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$proportional_width_top = $row["proportional"];
 	$proportional_width_sub = $row["proportional_sub"];
 ?>
