@@ -75,8 +75,8 @@ Select a menu to add items to:
     <option value="-not selected-">-not selected-</option>
 <?php
 	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menus`";
-	$result = mysql_query($query, $bwb_link);
-	while($row = mysql_fetch_array($result))
+	$result = $bwb_dbh->query($query);
+	while($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
 		$menu_name = $row['menu_name'];
 		$description = $row['description'];
@@ -116,22 +116,22 @@ Select a menu to add items to:
 	$menu_css_table = $menu . "_css" ;
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = 'ul.nav" . $suffix . ", .nav" . $suffix . " ul'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count < 1)
 	{
 		echo "CSS menu parameters have not been set.  Please click <a href='edit_css_menu_params.php'>here</a> to setup the CSS menu parameters";
 		exit;
 	}
-	$row = mysql_fetch_array($result);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["border"] == -2)
 		$load_defaults = 1;
 	else
 		$load_defaults = 0;
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.top_level_a" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (!is_null($row["font"]) && ($row["font"] != ""))
 		$top_level_font = $row["font"];
 	elseif($load_defaults == 1)
@@ -205,8 +205,8 @@ Select a menu to add items to:
 		
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.sub_level_1_a" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (!is_null($row["font"]) && ($row["font"] != ""))
 		$sub_level_1_font = $row["font"];
 	elseif($load_defaults == 1)
@@ -278,8 +278,8 @@ Select a menu to add items to:
 		
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.sub_level_2_a" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (!is_null($row["font"]) && ($row["font"] != ""))
 		$sub_level_2_font = $row["font"];
 	elseif($load_defaults == 1)
@@ -352,8 +352,8 @@ Select a menu to add items to:
 
 //	$query = "SELECT * FROM " . $menu_css_table . " WHERE class = '.nav" . $suffix . " a:hover'";
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.top_level_li" . $suffix . " A:hover'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (!is_null($row["text_color"]) && ($row["text_color"] != ""))
 		$top_level_text_color_hover = $row["text_color"];
 	elseif($load_defaults == 1)
@@ -363,8 +363,8 @@ Select a menu to add items to:
 		
 //////////////////// new /////////////////////////////////////
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.sub_level_1_li" . $suffix . " A:hover'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (!is_null($row["text_color"]) && ($row["text_color"] != ""))
 		$sub_level_1_text_color_hover = $row["text_color"];
 	elseif($load_defaults == 1)
@@ -373,8 +373,8 @@ Select a menu to add items to:
 		$sub_level_1_text_color_hover = "-not set-";
 		
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.sub_level_2_li" . $suffix . " A:hover'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (!is_null($row["text_color"]) && ($row["text_color"] != ""))
 		$sub_level_2_text_color_hover = $row["text_color"];
 	elseif($load_defaults == 1)
@@ -384,8 +384,8 @@ Select a menu to add items to:
 //////////////////////////////////////////////////////////////
 
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = 'ul.nav" . $suffix . " li:hover, .nav" . $suffix . " ul li a:hover'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 /*
 	if (!is_null($row["text_color"])  && ($row["text_color"] != ""))
 		$sub_level_1_text_color_hover = $row["text_color"];
@@ -407,8 +407,8 @@ Select a menu to add items to:
 		
 		
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = 'ul.nav" . $suffix . ", .nav" . $suffix . " ul, .nav" . $suffix . " ul li a'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (!is_null($row["bkgd_color"]) && ($row["bkgd_color"] != ""))
 		$sub_level_background_color = $row["bkgd_color"];
 	elseif($load_defaults == 1)
@@ -419,8 +419,8 @@ Select a menu to add items to:
 	
 		
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = 'ul.nav" . $suffix . ">li'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (!is_null($row["bkgd_color"]) && ($row["bkgd_color"] != ""))
 		$top_level_background_color = $row["bkgd_color"];
 	elseif($load_defaults == 1)
@@ -466,8 +466,8 @@ Select a menu to add items to:
 		
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = 'ul.nav" . $suffix . ", .nav" . $suffix . " ul'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["border"] > -1)
 		$top_level_block_border_width = $row["border"];
 	elseif($load_defaults == 1)
@@ -509,8 +509,8 @@ Select a menu to add items to:
 	}
 		
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = 'ul.nav" . $suffix . " li>ul'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["border"] > -1)
 		$sub_level_block_border_width = $row["border"];
 	elseif($load_defaults == 1)
@@ -552,8 +552,8 @@ Select a menu to add items to:
 	}
 		
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.nav" . $suffix . " ul li a'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["border"] > -1)
 		$sub_level_item_border_width = $row["border"];
 	else
@@ -591,8 +591,8 @@ Select a menu to add items to:
 	}
 		
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = 'ul.nav" . $suffix . " li:active, .nav" . $suffix . " ul li a:active'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if (!is_null($row["text_color"])   && ($row["text_color"] != ""))
 		$sub_level_1_text_color_active = $row["text_color"];
 	else
@@ -629,8 +629,8 @@ Select a menu to add items to:
 						echo ">-not selected-</option>\n";
 						  
 					 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "fonts ORDER BY font";
-						$result = mysql_query($query, $bwb_link);
-						while ($row = mysql_fetch_array($result))
+						$result = $bwb_dbh->query($query);
+						while ($row = $result->fetch(PDO::FETCH_ASSOC))
 						{
 							$tmp_font = $row['font'];
 							$websafe = $row['websafe'];
@@ -767,8 +767,8 @@ Select a menu to add items to:
 						echo ">-not selected-</option>\n";
 							
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "fonts ORDER BY font";
-						$result = mysql_query($query, $bwb_link);
-						while ($row = mysql_fetch_array($result))
+						$result = $bwb_dbh->query($query);
+						while ($row = $result->fetch(PDO::FETCH_ASSOC))
 						{
 							$tmp_font = $row['font'];
 							$websafe = $row['websafe'];
@@ -884,8 +884,8 @@ Select a menu to add items to:
 						echo ">-not selected-</option>\n";
 						  
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "fonts ORDER BY font";
-						$result = mysql_query($query, $bwb_link);
-						while ($row = mysql_fetch_array($result))
+						$result = $bwb_dbh->query($query);
+						while ($row = $result->fetch(PDO::FETCH_ASSOC))
 						{
 							$tmp_font = $row['font'];
 							$websafe = $row['websafe'];
