@@ -112,8 +112,8 @@ Select a menu to add items to:
     <option value="-not selected-">-not selected-</option>
 <?php
 	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menus` WHERE `menu_type` = 1";
-	$result = mysql_query($query, $bwb_link);
-	while($row = mysql_fetch_array($result))
+	$result = $bwb_dbh->query($query);
+	while($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
 		$menu_name = $row['menu_name'];
 		$description = $row['description'];
@@ -145,8 +145,8 @@ if (($menu == "-not selected-") || ($menu == ""))
 else
 {	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_css WHERE class = '.m0l0iout" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["font"]) $top_level_font_out = $row["font"];
 	else $top_level_font_out = "Tahoma, Verdana, Geneva, Arial, Helvetica, sans-serif";
 	if ($row["font_size"]) $top_level_font_size_out = $row["font_size"];
@@ -177,8 +177,8 @@ else
 	else $top_level_shadow_blur_out = 0;
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_css WHERE class = '.m0l0iover" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["font"]) $top_level_font_over = $row["font"];
 	else $top_level_font_over = "Tahoma, Verdana, Geneva, Arial, Helvetica, sans-serif";
 	if ($row["font_size"]) $top_level_font_size_over = $row["font_size"];
@@ -209,8 +209,8 @@ else
 	else $top_level_shadow_blur_over = 0;
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_css WHERE class = '.m0l0oout" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["bkgd_color"]) $top_level_bkgd_color_out = $row["bkgd_color"];
 	else $top_level_bkgd_color_out = "-not set-";
 	if ($row["bkgd_opacity"]) $top_level_bkgd_opacity_out = $row["bkgd_opacity"];
@@ -221,8 +221,8 @@ else
 	else $top_level_border_color_out = "-not set-";
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_css WHERE class = '.m0l0oover" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["bkgd_color"]) $top_level_bkgd_color_over = $row["bkgd_color"];
 	else $top_level_bkgd_color_over = "-not set-";
 	if (!is_null($row["border"])) $top_level_border_over = $row["border"];
@@ -231,8 +231,8 @@ else
 	else $top_level_border_color_over = "-not set-";
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_css WHERE class = '.m0l1iout" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["font"]) $sub_level_1_font_out = $row["font"];
 	else $sub_level_1_font_out = "Tahoma, Verdana, Geneva, Arial, Helvetica, sans-serif";
 	if ($row["font_size"]) $sub_level_1_font_size_out = $row["font_size"];
@@ -263,8 +263,8 @@ else
 	else $sub_level_1_shadow_blur_out = 0;
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_css WHERE class = '.m0l1iover" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["font"]) $sub_level_1_font_over = $row["font"];
 	else $sub_level_1_font_over = "Tahoma, Verdana, Geneva, Arial, Helvetica, sans-serif";
 	if ($row["font_size"]) $sub_level_1_font_size_over = $row["font_size"];
@@ -295,8 +295,8 @@ else
 	else $sub_level_1_shadow_blur_over = 0;
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_css WHERE class = '.m0l1oout" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["bkgd_color"]) $sub_level_1_bkgd_color_out = $row["bkgd_color"];
 	else $sub_level_1_bkgd_color_out = "-not set-";
 	if ($row["bkgd_opacity"]) $sub_level_1_bkgd_opacity_out = $row["bkgd_opacity"];
@@ -307,8 +307,8 @@ else
 	else $sub_level_1_border_color_out = "-not set-";
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_css WHERE class = '.m0l1oover" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["bkgd_color"]) $sub_level_1_bkgd_color_over = $row["bkgd_color"];
 	else $sub_level_1_bkgd_color_over = "-not set-";
 	if (!is_null($row["border"])) $sub_level_1_border_over = $row["border"];
@@ -317,8 +317,8 @@ else
 	else $sub_level_1_border_color_over = "-not set-";
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_css WHERE class = '.m0l2iout" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["font"]) $sub_level_2_font_out = $row["font"];
 	else $sub_level_2_font_out = "Tahoma, Verdana, Geneva, Arial, Helvetica, sans-serif";
 	if ($row["font_size"]) $sub_level_2_font_size_out = $row["font_size"];
@@ -349,8 +349,8 @@ else
 	else $sub_level_2_shadow_blur_out = 0;
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_css WHERE class = '.m0l2iover" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["font"]) $sub_level_2_font_over = $row["font"];
 	else $sub_level_2_font_over = "Tahoma, Verdana, Geneva, Arial, Helvetica, sans-serif";
 	if ($row["font_size"]) $sub_level_2_font_size_over = $row["font_size"];
@@ -381,8 +381,8 @@ else
 	else $sub_level_2_shadow_blur_over = 0;
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_css WHERE class = '.m0l2oout" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["bkgd_color"]) $sub_level_2_bkgd_color_out = $row["bkgd_color"];
 	else $sub_level_2_bkgd_color_out = "-not set-";
 	if ($row["bkgd_opacity"]) $sub_level_2_bkgd_opacity_out = $row["bkgd_opacity"];
@@ -393,8 +393,8 @@ else
 	else $sub_level_2_border_color_out = "-not set-";
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_css WHERE class = '.m0l2oover" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["bkgd_color"]) $sub_level_2_bkgd_color_over = $row["bkgd_color"];
 	else $sub_level_2_bkgd_color_over = "-not set-";
 	if (!is_null($row["border"])) $sub_level_2_border_over = $row["border"];
@@ -433,8 +433,8 @@ else
 					<select name="top_level_font_out">
 					<?php
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "fonts ORDER BY font";
-						$result = mysql_query($query, $bwb_link);
-						while ($row = mysql_fetch_array($result))
+						$result = $bwb_dbh->query($query);
+						while ($row = $result->fetch(PDO::FETCH_ASSOC))
 						{
 							$font = $row['font'];
 							$websafe = $row['websafe'];
@@ -540,8 +540,8 @@ else
 					<select name="top_level_font_over">
 					<?php
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "fonts ORDER BY font";
-						$result = mysql_query($query, $bwb_link);
-						while ($row = mysql_fetch_array($result))
+						$result = $bwb_dbh->query($query);
+						while ($row = $result->fetch(PDO::FETCH_ASSOC))
 						{
 							$font = $row['font'];
 							$websafe = $row['websafe'];
@@ -710,8 +710,8 @@ else
 					<select name="sub_level_1_font_out">
 					<?php
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "fonts ORDER BY font";
-						$result = mysql_query($query, $bwb_link);
-						while ($row = mysql_fetch_array($result))
+						$result = $bwb_dbh->query($query);
+						while ($row = $result->fetch(PDO::FETCH_ASSOC))
 						{
 							$font = $row['font'];
 							$websafe = $row['websafe'];
@@ -817,8 +817,8 @@ else
 					<select name="sub_level_1_font_over">
 					<?php
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "fonts ORDER BY font";
-						$result = mysql_query($query, $bwb_link);
-						while ($row = mysql_fetch_array($result))
+						$result = $bwb_dbh->query($query);
+						while ($row = $result->fetch(PDO::FETCH_ASSOC))
 						{
 							$font = $row['font'];
 							$websafe = $row['websafe'];
@@ -987,8 +987,8 @@ else
 					<select name="sub_level_2_font_out">
 					<?php
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "fonts ORDER BY font";
-						$result = mysql_query($query, $bwb_link);
-						while ($row = mysql_fetch_array($result))
+						$result = $bwb_dbh->query($query);
+						while ($row = $result->fetch(PDO::FETCH_ASSOC))
 						{
 							$font = $row['font'];
 							$websafe = $row['websafe'];
@@ -1094,8 +1094,8 @@ else
 					<select name="sub_level_2_font_over">
 					<?php
 						$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "fonts ORDER BY font";
-						$result = mysql_query($query, $bwb_link);
-						while ($row = mysql_fetch_array($result))
+						$result = $bwb_dbh->query($query);
+						while ($row = $result->fetch(PDO::FETCH_ASSOC))
 						{
 							$font = $row['font'];
 							$websafe = $row['websafe'];
