@@ -39,11 +39,11 @@
 var pages = new Array();
 <?php
 	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
-	$result = mysql_query($query, $bwb_link);
-	$num_results = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$num_results = $result->rowCount();
 	for ($j = 0; $j < $num_results; $j++)
 	{
-		$row = mysql_fetch_array($result);
+		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$page_name = $row["page_name"];
 		echo "pages[$j] = '$page_name';\n";
 	}
@@ -411,11 +411,11 @@ function PopulateUsers(rows_str)
 	echo "<td>&nbsp;</td>\n";
 	echo "</tr>\n";
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "schedule ORDER BY EventDateSort";
-	$result = mysql_query($query, $bwb_link);
-	$num_results = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$num_results = $result->rowCount();
 	for ($i = 0; $i < $num_results; $i++)
 	{
-		$row = mysql_fetch_array($result);
+		$row = $result->fetch(PDO::FETCH_ASSOC);
 		
 		$ID = $row["ID"];
 		$Description = $row["Description"];
@@ -450,11 +450,11 @@ function PopulateUsers(rows_str)
 		echo "<select name=\"selectPage$i\" onChange=\"document.getElementById('URL$i').value=this.value+'.php';\">\n";
 		echo "<option value=''>-not selected-</option>\n";
 		$query2 = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
-		$result2 = mysql_query($query2, $bwb_link);
-		$num_results2 = mysql_num_rows($result2);
+		$result2 = $bwb_dbh->query($query2);
+		$num_results2 = $result2->rowCount();
 		for ($j = 0; $j < $num_results2; $j++)
 		{
-			$row2 = mysql_fetch_array($result2);
+			$row2 = $result2->fetch(PDO::FETCH_ASSOC);
 			$page_name = $row2["page_name"];
 			$page_name_tmp = $page_name . ".php";
 			if ($page_name_tmp == $URL)
@@ -475,9 +475,9 @@ function PopulateUsers(rows_str)
 		echo "<select name=\"selectUserTable$i\" id=\"selectUserTable$i\" onChange=\"RetrieveUsers(this.value, $i);\">\n";
 		echo "<option value=''>-not selected-</option>\n";
 		$query2 = "SHOW TABLES";
-		$result2 = mysql_query($query2, $bwb_link);
-		$num_results2 = mysql_num_rows($result2);
-		while ($row2 = mysql_fetch_array($result2))
+		$result2 = $bwb_dbh->query($query2);
+		$num_results2 = $result2->rowCount();
+		while ($row2 = $result2->fetch(PDO::FETCH_ASSOC))
 		{
 			$tmp_table = $row2[0];
 			if ((substr($tmp_table, 0, strlen(BWB_TABLE_PREFIX)) != BWB_TABLE_PREFIX) || (BWB_TABLE_PREFIX == ""))
@@ -497,8 +497,8 @@ function PopulateUsers(rows_str)
 		if ($user_table != "")
 		{
 			$query2 = "SELECT `UserID` FROM `" . $user_table . "`";
-			$result2 = mysql_query($query2, $bwb_link);
-			while ($row2 = mysql_fetch_array($result2))
+			$result2 = $bwb_dbh->query($query2);
+			while ($row2 = $result2->fetch(PDO::FETCH_ASSOC))
 			{
 				$tmp_UserID = $row2["UserID"];
 				if (($tmp_UserID != "") && (!is_null($tmp_UserID)))
@@ -517,8 +517,8 @@ function PopulateUsers(rows_str)
 		echo "<select name=\"selectAccessLevel$i\" id=\"selectAccessLevel$i\">\n";
 		echo "<option value=''>-not selected-</option>\n";
 		$query2 = "SELECT `access_level` FROM `" . BWB_TABLE_PREFIX . "access_levels`";
-		$result2 = mysql_query($query2, $bwb_link);
-		while ($row2 = mysql_fetch_array($result2))
+		$result2 = $bwb_dbh->query($query2);
+		while ($row2 = $result2->fetch(PDO::FETCH_ASSOC))
 		{
 			$tmp_AccessLevel = $row2["access_level"];
 			if ($tmp_AccessLevel == $AccessLevel)
@@ -549,11 +549,11 @@ function PopulateUsers(rows_str)
 		echo "<select name=\"selectPage$k\" onChange=\"document.getElementById('URL$k').value=this.value+'.php';\">\n";
 		echo "<option value=''>-not selected-</option>\n";
 		$query2 = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
-		$result2 = mysql_query($query2, $bwb_link);
-		$num_results2 = mysql_num_rows($result2);
+		$result2 = $bwb_dbh->query($query2);
+		$num_results2 = $result2->rowCount();
 		for ($j = 0; $j < $num_results2; $j++)
 		{
-			$row2 = mysql_fetch_array($result2);
+			$row2 = $result2->fetch(PDO::FETCH_ASSOC);
 			$page_name = $row2["page_name"];
 			echo "<option value='$page_name'>$page_name</option>\n";
 		}
@@ -567,9 +567,9 @@ function PopulateUsers(rows_str)
 		echo "<select name=\"selectUserTable$k\" id=\"selectUserTable$k\" onChange=\"RetrieveUsers(this.value, $k);\">\n";
 		echo "<option value=''>-not selected-</option>\n";
 		$query2 = "SHOW TABLES";
-		$result2 = mysql_query($query2, $bwb_link);
-		$num_results2 = mysql_num_rows($result2);
-		while ($row2 = mysql_fetch_array($result2))
+		$result2 = $bwb_dbh->query($query2);
+		$num_results2 = $result2->rowCount();
+		while ($row2 = $result2->fetch(PDO::FETCH_ASSOC))
 		{
 			$tmp_table = $row2[0];
 			if ((substr($tmp_table, 0, strlen(BWB_TABLE_PREFIX)) != BWB_TABLE_PREFIX) || (BWB_TABLE_PREFIX == ""))
@@ -584,8 +584,8 @@ function PopulateUsers(rows_str)
 		if ($user_table != "")
 		{
 			$query2 = "SELECT `UserID` FROM `" . $user_table . "`";
-			$result2 = mysql_query($query2, $bwb_link);
-			while ($row2 = mysql_fetch_array($result2))
+			$result2 = $bwb_dbh->query($query2);
+			while ($row2 = $result2->fetch(PDO::FETCH_ASSOC))
 			{
 				$tmp_UserID = $row2["UserID"];
 				if (($tmp_UserID != "") && (!is_null($tmp_UserID)))
@@ -599,8 +599,8 @@ function PopulateUsers(rows_str)
 		echo "<select name=\"selectAccessLevel$k\" id=\"selectAccessLevel$k\">\n";
 		echo "<option value=''>-not selected-</option>\n";
 		$query2 = "SELECT `access_level` FROM `" . BWB_TABLE_PREFIX . "access_levels`";
-		$result2 = mysql_query($query2, $bwb_link);
-		while ($row2 = mysql_fetch_array($result2))
+		$result2 = $bwb_dbh->query($query2);
+		while ($row2 = $result2->fetch(PDO::FETCH_ASSOC))
 		{
 			$tmp_AccessLevel = $row2["access_level"];
 			echo "<option value='$tmp_AccessLevel'>$tmp_AccessLevel</option>\n";
@@ -669,8 +669,8 @@ function PopulateUsers(rows_str)
 window.onload = function(){
 <?php
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "schedule ORDER BY EventDateSort";
-	$result = mysql_query($query, $bwb_link);
-	$num_results = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$num_results = $result->rowCount();
 	for ($i = 0; $i < $num_results + $spares; $i++)
 		echo <<<END
 		
