@@ -18,7 +18,7 @@ $referers = array($server_name_www, $server_name);
 // Module for performaing actual email operation.
 include("mime_mail.inc");
 // DB connection for retrieving HTML message format for message back to inquirer, etc.
-include("../connect/db_connection.php");
+include("../connect/db_connect.php");
 include("../connect/config.php");
 
 // If alternate go back specified, then use that if any errors.  This is usefule if sending page session expires if back button is used.
@@ -211,7 +211,7 @@ if ($email_required)
 		exit;
 	}
 }
-	
+
 // Check referers to make sure SPAM bot is not trying to brake in.
 if (!check_referer($referers))
 {
@@ -302,21 +302,25 @@ if ($email_ext == "@aol.com")	// AOL emails
 
 /////////////////////////////////////////////////////////////////////////
 // Pipe data to table.  Create table if it does not exist.
+// But first clean entire POST var array:
+foreach ($_POST as $key => $value)
+	$_POST[$key] = CleanVar($value);
+	
 $table_name = $_POST['table_name'];
 if (isset($table_name) && ($table_name != ""))
 {	
-	$table_name = mysql_real_escape_string($table_name);
 	// Check to see if table exists.
+	$table_name = CleanVar($table_name);
 	$query = "SELECT COUNT(*) FROM information_schema.tables WHERE table_schema = '[$bwb_database]' AND table_name = '[$table_name]'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	if ($row["COUNT"] < 1)
 	{
 		$query = "CREATE TABLE IF NOT EXISTS `$table_name` (`id` bigint(20) NOT NULL auto_increment, ";
 		// Add column for each key.
 		foreach ($_POST as $key => $value)
 		{
-			$key = mysql_real_escape_string($key);
+			$key = CleanVar($key);
 			if (in_array($key, $longtext_fields))
 				$query .= "`$key` longtext default NULL, ";
 			elseif (!in_array($key, $ignore_fields))
@@ -326,17 +330,17 @@ if (isset($table_name) && ($table_name != ""))
 		$query .= "`created` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP, ";
 		// Add primary key.
 		$query .= "PRIMARY KEY  (`id`) ) TYPE=MyISAM AUTO_INCREMENT=1";
-		$result = mysql_query($query, $bwb_link);
+		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	// Add any missing columns due to new fields in form.
 	foreach ($_POST as $key => $value)
 	{
-		$key = mysql_real_escape_string($key);
+		$key = CleanVar($key);
 		$field_found = false;
 		$query ="SHOW COLUMNS FROM $bwb_database.$table_name";
-		$result = mysql_query($query, $bwb_link);
-		while ($row = mysql_fetch_array($result))
+		$result = $bwb_dbh->query($query);
+		while ($row = $result->fetch(PDO::FETCH_ASSOC))
 		{
 			if ($row['field'] == $key)
 				$field_found = true;
@@ -344,15 +348,15 @@ if (isset($table_name) && ($table_name != ""))
 		if (in_array($key, $longtext_fields))
 		{
 			$query2 = "ALTER TABLE `$table_name` ADD `$key` longtext NULL ";
-			$result2 = mysql_query($query2, $bwb_link);
+			$cnt = $bwb_dbh->exec($query2);
 		}
 		elseif (!$field_found && !in_array($key, $ignore_fields))
 		{
 			$query2 = "ALTER TABLE `$table_name` ADD `$key` VARCHAR( 255 ) NULL ";
-			$result2 = mysql_query($query2, $bwb_link);
+			$cnt = $bwb_dbh->exec($query2);
 		}
 	}
-	
+
 	// If no_duplicates defined, then check to see if record already exists.
 	$no_duplicates = $_POST['no_duplicates'];
 	if ($no_duplicates)
@@ -362,8 +366,8 @@ if (isset($table_name) && ($table_name != ""))
 		{
 			$unique_field_val = $_POST[$value];
 			$query = "SELECT * FROM " . $table_name . " WHERE `" . $value . "`='" . $unique_field_val . "'";
-			$result = mysql_query($query, $bwb_link);
-			if (mysql_num_rows($result) > 0)
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() > 0)
 			{	
 				$err = "<b>$unique_field_val</b> already exists for the <b>$value</b> field.  You will need to enter a different $value.<br />\n<a href='$go_back'>Click here</a> to return to the previous page, or use your 'Back' button.";
 				$button_label = "OK";
@@ -372,7 +376,7 @@ if (isset($table_name) && ($table_name != ""))
 			}
 		}
 	}
-	
+
 	// Insert row.
 	$query = "INSERT INTO `$table_name` SET ";
 	$first = true;
@@ -385,12 +389,12 @@ if (isset($table_name) && ($table_name != ""))
 		else
 			unset($_POST['userid']);
 	}
+
 	foreach ($_POST as $key => $value)
 	{
-		$key = mysql_real_escape_string($key);
+		$key = CleanVar($key);
 		if (!in_array($key, $ignore_fields))
 		{
-			$value = mysql_real_escape_string($value);
 			//If password found, encrypt password using user ID,last name or email address as key.
 			if ($key == "password")
 			{
@@ -414,18 +418,18 @@ if (isset($table_name) && ($table_name != ""))
 			$query .= "`$key` = '$value'";
 		}
 	}
-	$result = mysql_query($query, $bwb_link);
-	
+	$cnt = $bwb_dbh->exec($query);
+
 	// Get last inserted id for possible use by other modules.
-	$last_id = mysql_insert_id($bwb_link);
-	
+	$last_id = $bwb_dbh->lastInsertId();
+
 	/////////////////////////////////////////////
 	// If table is user table for page access, then see if need to activate right now.
 	$query = "SELECT option_value FROM `" . BWB_TABLE_PREFIX . "options_selected` WHERE option_name='ActivateNewUsersAutomatically'";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$activate = $row['option_value'];
-	
+
 	if ($activate == 1)
 	{
 		$got_active = false;
@@ -434,8 +438,8 @@ if (isset($table_name) && ($table_name != ""))
 		$got_userid = false;
 		$got_password = false;
 		$query ="SHOW COLUMNS FROM $bwb_database.$table_name";
-		$result = mysql_query($query, $bwb_link);
-		while ($row = mysql_fetch_array($result))
+		$result = $bwb_dbh->query($query);
+		while ($row = $result->fetch(PDO::FETCH_ASSOC))
 		{
 			if ($row['field'] == "Active")
 				$got_active = true;
@@ -451,7 +455,7 @@ if (isset($table_name) && ($table_name != ""))
 		if ($got_active && $got_session && $got_ip && $got_userid && $got_password)
 		{
 			$query = "UPDATE `$table_name` SET `Active`=1 WHERE id=$last_id";
-			$result = mysql_query($query, $bwb_link);
+			$cnt = $bwb_dbh->exec($query);
 		}
 	}
 	/////////////////////////////////////////////
@@ -471,10 +475,9 @@ if (isset($html_message_page) && ($html_message_page != ""))
 	else
 		$userid = "";
 	
-	$html_message_page = mysql_real_escape_string($html_message_page);
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name = '". $html_message_page . "'";
-	$result = mysql_query($query, $bwb_link);
-	if ($row = mysql_fetch_array($result))
+	$result = $bwb_dbh->query($query);
+	if ($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
 		$html_msg = stripslashes($row["page_content"]);
 		$html_msg = str_replace("[FIRST_NAME]", $first_name, $html_msg);
@@ -681,5 +684,12 @@ function strpos_a($haystack, $needle)
      return false;
 }
 
+////////////////////////////////////////////////////////////
+function CleanVar($var)
+{
+	$bad_strings = array("INSERT", "UPDATE", "SELECT", "DROP", "TRUNCATE", "CREATE");
+	$var = str_ireplace($bad_strings, "", $var);
+	return($var);
+}
 
 ?>
\ No newline at end of file
