@@ -7,19 +7,19 @@
 // 
 //
 
-function copy_table($src_table, $dest_table, $link, $database)
+function copy_table($src_table, $dest_table, $dbh, $database)
 	{
 		$query = "TRUNCATE TABLE `" . $dest_table;
-		$result = mysql_query($query, $link);
+		$cnt = $dbh->exec($query);
 			
 		$query = "SELECT * FROM " . $src_table;
-		$result = mysql_query($query, $link);
-		while ($row = mysql_fetch_array($result))
+		$result = $dbh->query($query);
+		while ($row = $result->fetch(PDO::FETCH_ASSOC))
 		{
 			$sql = "INSERT INTO " . $dest_table . " SET ";
 			$query2 = "SHOW COLUMNS FROM " . $src_table . " FROM " . $database;
-			$result2 = mysql_query($query2, $link);
-			while ($column = mysql_fetch_array($result2))
+			$result2 = $dbh->query($query2);
+			while ($column = $result2->fetch(PDO::FETCH_ASSOC))
 			{
 				if ($column['Field'] != "id")
 				{
@@ -30,7 +30,7 @@ function copy_table($src_table, $dest_table, $link, $database)
 				}
 			}
 //			echo "sql: $sql\n<br><br>\n";
-			$result3  = mysql_query($sql, $link);
+			$cnt = $dbh->exec($sql);
 		}
 	}
 	
