@@ -7,7 +7,7 @@
 ?>
 <HTML>
 <HEAD>
-<TITLE>Little Blossoms Arts Inventory Manager</TITLE>
+<TITLE>Zen Cart Art Inventory Manager</TITLE>
 <STYLE>
 TH
 {
@@ -90,19 +90,21 @@ function parseDescription()
 <?
 ini_set('max_execution_time', 2000);
 
+include ("../connect/db_connect_2.php");
+include ("../connect/db_connect.php");
 include ("image_processing.php");
-include ("../connect/db_connection_2.php");
+
 
 ///////////////////////////////////////////////////////////////////////////////////////
-function read_columns($view_id, $link)
+function read_columns($view_id, $dbh)
 {
     global $columns, $column_types;
 
     $sql = "SELECT * FROM view_fields WHERE view_id = $view_id ORDER BY vf_Order, vf_id";
-    if (!($ret = mysql_query($sql, $link)))
+    if (!($ret = $dbh->query($sql)))
         return;
 
-    while ($row = mysql_fetch_assoc($ret))
+    while ($row = $ret->fetch(PDO::FETCH_ASSOC))
     {
 	$columns[$row["vf_ColumnName"]] = $row["vf_DisplayName"];
 	if ($row["vf_FieldType"] != null)
@@ -118,17 +120,17 @@ function read_columns($view_id, $link)
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////
-function read_field_values($field, $query)
+function read_field_values($field, $query, $dbh)
 {
     global $enums, $column_types;
 
     $sql = $query;
-    if (!($ret = mysql_query($sql)))
+    if (!($ret = $dbh->query($sql)))
         return;
 
     if ($column_types[$field] == 'select' || $column_types[$field] == 'multiselect')
     {
-        while ($row = mysql_fetch_assoc($ret))
+        while ($row = $ret->fetch(PDO::FETCH_ASSOC))
         {
 	    if (!is_array($enums[$field]))
 		$enums[$field] = array();
@@ -137,22 +139,22 @@ function read_field_values($field, $query)
     }
     else
     {
-	$row = mysql_fetch_assoc($ret);
+	$row = $ret->fetch(PDO::FETCH_ASSOC);
 	$enums[$field] = $row["Value"];
     }
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
-function read_enums($link)
+function read_enums($dbh)
 {
     global $enums;
 	
 	//Add enumerations from manufacturers table.
 	$sql = "SELECT * FROM `zen_manufacturers` ORDER BY `manufacturers_id`";
-    if (!($ret = mysql_query($sql, $link)))
+    if (!($ret = $dbh->query($sql)))
         return;
 		
-	while ($row = mysql_fetch_assoc($ret))
+	while ($row = $ret->fetch(PDO::FETCH_ASSOC))
     {
 	if (!is_array($enums["manufacturers_id"]))
 	    $enums["manufacturers_id"] = array();
@@ -161,10 +163,10 @@ function read_enums($link)
 	
 	//Add enumerations from categories table.
 	$sql = "SELECT * FROM `zen_categories_description` ORDER BY `categories_id`";
-    if (!($ret = mysql_query($sql, $link)))
+    if (!($ret = $dbh->query($sql)))
         return;
 		
-	while ($row = mysql_fetch_assoc($ret))
+	while ($row = $ret->fetch(PDO::FETCH_ASSOC))
     {
 	if (!is_array($enums["master_categories_id"]))
 	    $enums["master_categories_id"] = array();
@@ -228,15 +230,15 @@ function input_html($column_types, $column, $value, $attribs)
 }
 
 ////////////////////////////////////////////////////////////////////////////
-function get_column_info($table)
+function get_column_info($table, $dbh)
 {
     global $column_types;
 
     $sql = "SHOW COLUMNS FROM $table";
-    if (!($ret = mysql_query($sql)))
+    if (!($ret = $dbh->query($sql)))
         die("Error: Could not show columns");
 
-    while ($row = mysql_fetch_assoc($ret))
+    while ($row = $ret->fetch(PDO::FETCH_ASSOC))
 	$array[$row["Field"]] = $row["Type"];
 
     # now add in known column types
@@ -276,12 +278,12 @@ function create_images($srcfile, $destfile_fs, $destfile_tn, $destdir)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-function re_crop_image($link)
+function re_crop_image()
 {
 	$crop_area = $_POST['crop_area'];
 	$crop_percent = $_POST['crop_percent'];
 	
-	$image_folder = get_image_folder($_POST["products_id"], $link);
+	$image_folder = get_image_folder($_POST["products_id"]);
 	$destdir = getenv('DOCUMENT_ROOT') . "/inventory_images/" . $image_folder;
 
 	$destfile_tn = $_POST['thumbnail_image'];
@@ -307,15 +309,15 @@ function create_column_list($array)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-function write_table($array, $link)
+function write_table($array, $dbh)
 {
     // assume $array already has addslashes run on it
     global $columns, $view_id, $enums;
 
-    $table_info = get_column_info('zen_products');
+    $table_info = get_column_info('zen_products', $dbh);
         
     echo <<<END
-<FORM method=post action="manage_inventory.php" name="Inventory" enctype="multipart/form-data" onSubmit="return sendMe()">
+<FORM method="post" action="manage_inventory.php" name="Inventory" enctype="multipart/form-data" onSubmit="return sendMe()">
 <TABLE>
 <TR>
 <TD valign='top'>
@@ -340,7 +342,7 @@ END;
 		if (!preg_match("/.jpg/i", $val))
 		    $img .= ".jpg";
 
-		$folder = get_image_folder($array["products_id"], $link);
+		$folder = get_image_folder($array["products_id"]);
 		
 		$tag .= "$val" . '<br><IMG src="/inventory_images/'
 		    . $folder . "/tn/" . htmlspecialchars($img) . '">';
@@ -370,7 +372,7 @@ END;
 			if (!preg_match("/.jpg/i", $val))
 				$img .= ".jpg";
 	
-			$folder = get_image_folder($array["products_id"], $link);
+			$folder = get_image_folder($array["products_id"]);
 			
 			$tag .= "<br>$val" . '<br><IMG src="/inventory_images/'
 				. $folder . "/fs/" . htmlspecialchars($img) . '">';	
@@ -502,10 +504,12 @@ END;
 }
 
 ///////////////////////////////////////////////////////////////
-function do_search($view_id, $link)
+function do_search($view_id, $dbh)
 {
-    $ret = mysql_query("SELECT view_Criteria FROM view_names WHERE view_id = $view_id");
-    $row = mysql_fetch_assoc($ret);
+	$query = "SELECT `view_Criteria` FROM `view_names` WHERE `view_id`='$view_id'";
+    $ret = $dbh->query($query);
+    $row = $ret->fetch(PDO::FETCH_ASSOC);
+	
     if ($row["view_Criteria"] != null)
 	$criteria = "AND " . $row["view_Criteria"];
 
@@ -522,8 +526,8 @@ function do_search($view_id, $link)
 	else
 	    $where = "WHERE 1=1 $criteria";
 
-	$ret = mysql_query("SELECT COUNT(*) FROM zen_products $where");
-	$row = mysql_fetch_array($ret);
+	$ret = $dbh->query("SELECT COUNT(*) FROM zen_products $where");
+	$row = $ret->fetch(PDO::FETCH_ASSOC);
 	$count = $row[0];
 
 	if ($count != 1)
@@ -548,11 +552,11 @@ function do_search($view_id, $link)
 
     if ($sql)
     {
-	if (!($ret = mysql_query($sql)))
+	if (!($dbh->query($sql)))
 	    die("Error: Could not query '$sql'");
-	while ($row = mysql_fetch_array($ret))
+	while ($row = $ret->fetch(PDO::FETCH_ASSOC))
 	{
-	    write_table($row, $link);
+	    write_table($row);
 	    $count++;
 	}    
     
@@ -564,7 +568,7 @@ function do_search($view_id, $link)
 }
 
 ///////////////////////////////////////////////////////////////
-function do_update($link)
+function do_update($dbh)
 {
     if ($_POST["Update"] || $_POST["Next"] || $_POST["Previous"])
     {
@@ -577,7 +581,7 @@ function do_update($link)
 
 	if (is_uploaded_file($_FILES['IMAGE']['tmp_name']))
 	{
-		$image_folder = get_image_folder($_POST["products_id"], $link);
+		$image_folder = get_image_folder($_POST["products_id"]);
 		$dir = getenv('DOCUMENT_ROOT') . "/inventory_images/" . $image_folder;
 
 		$filename = str_replace("/", "", $_FILES['IMAGE']['name']);
@@ -607,8 +611,8 @@ function do_update($link)
 	{
 	    // we have to make sure that we don't update the modification date if there is no change
 	    $sql = "SELECT * FROM zen_products WHERE products_id = " . $_POST["products_id"];
-	    $ret = mysql_query($sql);
-	    $curdb = mysql_fetch_array($ret);
+	    $ret = $dbh->query($sql);
+	    $curdb = $ret->fetch(PDO::FETCH_ASSOC);
 
 	    foreach ($columns as $colname => $desc)
 	        if (addslashes($curdb[$colname]) != $_POST[$colname])
@@ -636,52 +640,52 @@ function do_update($link)
 	}
 	$sql = $verb . " INTO zen_products SET " . join($cols, ", ");
 
-	if (!($ret = mysql_query($sql)))
+	if (!($ret = $dbh->query($sql)))
 	{
-	    echo "Sorry, but there is an error in your data.<BR>" . mysql_error();
-		if (mysql_error() == "Unknown column 'products_name' in 'field list'")
+	    echo "Sorry, but there is an error in your data.<BR>" . $dbh->errorInfo();
+		if ($dbh->errorInfo() == "Unknown column 'products_name' in 'field list'")
 		{
 			$sql_alter = "ALTER TABLE `zen_products` ADD `products_name` varchar(64) NULL";
-			$result_alt = mysql_query($sql_alter);
+			$result_alt = $dbh->exec($sql_alter);
 		}
-		elseif (mysql_error() == "Unknown column 'thumbnail_image' in 'field list'")
+		elseif ($dbh->errorInfo() == "Unknown column 'thumbnail_image' in 'field list'")
 		{
 			$sql_alter = "ALTER TABLE `zen_products` ADD `thumbnail_image` varchar(255) NULL";
-			$result_alt = mysql_query($sql_alter);
+			$result_alt = $dbh->exec($sql_alter);
 		}
-		elseif (mysql_error() == "Unknown column 'search_term' in 'field list'")
+		elseif ($dbh->errorInfo() == "Unknown column 'search_term' in 'field list'")
 		{
 			$sql_alter = "ALTER TABLE `zen_products` ADD `search_term` varchar(255) NULL";
-			$result_alt = mysql_query($sql_alter);
+			$result_alt = $dbh->exec($sql_alter);
 		}
-		elseif (mysql_error() == "Unknown column 'products_description' in 'field list'")
+		elseif ($dbh->errorInfo() == "Unknown column 'products_description' in 'field list'")
 		{
 			$sql_alter = "ALTER TABLE `zen_products` ADD `products_description` TEXT NULL";
-			$result_alt = mysql_query($sql_alter);
+			$result_alt = $dbh->exec($sql_alter);
 		}
-		elseif (mysql_error() == "Unknown column 'width' in 'field list'")
+		elseif ($dbh->errorInfo() == "Unknown column 'width' in 'field list'")
 		{
 			$sql_alter = "ALTER TABLE `zen_products` ADD `width` double NULL";
-			$result_alt = mysql_query($sql_alter);
+			$result_alt = $dbh->exec($sql_alter);
 		}
-		elseif (mysql_error() == "Unknown column 'height' in 'field list'")
+		elseif ($dbh->errorInfo() == "Unknown column 'height' in 'field list'")
 		{
 			$sql_alter = "ALTER TABLE `zen_products` ADD `height` double NULL";
-			$result_alt = mysql_query($sql_alter);
+			$result_alt = $dbh->exec($sql_alter);
 		}
 	}
 	else
 	{
 	    if ($verb == "INSERT")
 		{
-			$products_id = mysql_insert_id();
+			$products_id = $dbh->lastInsertId();
 			echo "Created Item #" . $products_id;
-			copy_to_products_desc_table_etc($products_id, $verb, $link);
+			copy_to_products_desc_table_etc($products_id, $verb);
 		}
 		else
 		{
 			echo "Updated Item #" . $_POST['products_id'];
-			copy_to_products_desc_table_etc($_POST['products_id'], $verb, $link);
+			copy_to_products_desc_table_etc($_POST['products_id'], $verb);
 		}
 			
 //	    if ($_POST["Update"])
@@ -692,14 +696,14 @@ function do_update($link)
 }
 
 ///////////////////////////////////////////////////////////////
-function get_image_folder($products_id, $link)
+function get_image_folder($products_id)
 {
 	if ($products_id)
 	{
 		$query = "SELECT * FROM `zen_products` WHERE `products_id` = $products_id";
-		$result = mysql_query($query, $link);
-		$num_results = mysql_num_rows($result);
-		$row = mysql_fetch_array($result);
+		$result = $zen_dbh->query($query);
+		$num_results = $result->rowCount();
+		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$manufacturers_id = $row["manufacturers_id"];
 		$master_categories_id = $row["master_categories_id"];
 	}
@@ -710,15 +714,15 @@ function get_image_folder($products_id, $link)
 	}
 	
 	$query = "SELECT * FROM `zen_manufacturers` WHERE `manufacturers_id` = $manufacturers_id";
-	$result = mysql_query($query, $link);
-	$num_results = mysql_num_rows($result);
-	$row = mysql_fetch_array($result);
+	$result = $zen_dbh->query($query);
+	$num_results = $result->rowCount();
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$artist_folder = $row["image_folder"];
 	
 	$query = "SELECT * FROM `zen_categories_description` WHERE `categories_id` = $master_categories_id";
-	$result = mysql_query($query, $link);
-	$num_results = mysql_num_rows($result);
-	$row = mysql_fetch_array($result);
+	$result = $zen_dbh->query($query);
+	$num_results = $result->rowCount();
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$cat_folder = $row["categories_name"];
 	$cat_folder = str_replace(" ", "_", $cat_folder);
 	$cat_folder = strtolower($cat_folder);
@@ -728,12 +732,12 @@ function get_image_folder($products_id, $link)
 }
 
 ///////////////////////////////////////////////////////////////
-function copy_to_products_desc_table_etc($products_id, $verb, $link)
+function copy_to_products_desc_table_etc($products_id, $verb)
 {
 	$query = "SELECT * FROM `zen_products` WHERE `products_id` = $products_id";
-	$result = mysql_query($query, $link);
-	$num_results = mysql_num_rows($result);
-	$row = mysql_fetch_array($result);
+	$result = $zen_dbh->query($query);
+	$num_results = $result->rowCount();
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$products_name = $row["products_name"];
 	$products_description = $row["products_description"];
 	$categories_id = $row["master_categories_id"];
@@ -741,37 +745,39 @@ function copy_to_products_desc_table_etc($products_id, $verb, $link)
 	if ($verb == "INSERT")
 	{
 		$query = "INSERT INTO `zen_products_description` SET `products_id`=$products_id, `products_name`='$products_name', `products_description`='$products_description'";
-		$result = mysql_query($query, $link);
+		$cnt = $zen_dbh->exec($query);
 		$query = "INSERT INTO `zen_products_to_categories` SET `products_id`=$products_id, `categories_id`=$categories_id";
-		$result = mysql_query($query, $link);
+		$cnt = $zen_dbh->exec($query);
 	}
 	else
 	{
 		$query = "UPDATE `zen_products_description` SET `products_name`='$products_name', `products_description`='$products_description' WHERE `products_id`=$products_id";
-		$result = mysql_query($query, $link);
+		$cnt = $zen_dbh->exec($query);
 		$query = "UPDATE `zen_products_to_categories` SET `categories_id`='$categories_id' WHERE `products_id`=$products_id";
-		$result = mysql_query($query, $link);
+		$cnt = $zen_dbh->exec($query);
 	}
 }
 
 ///////////////////////////////////////////////////////////////////
 
 if ($_POST['Re_Crop'])
-	re_crop_image($zen_link);
+	re_crop_image();
 
-read_enums($zen_link);
-read_columns($view_id, $zen_link);
+read_enums($zen_dbh);
+
+read_columns($view_id, $zen_dbh);
+
+$search = do_search($view_id, $bwb_dbh);
+
+$update = do_update($zen_dbh);
 
-$search = do_search($view_id, $zen_link);
-$update = do_update($zen_link);
-	
 if ($_GET['Deleted'])
 	echo "Item deleted.";
 
 if ($_POST["Clear"])
-    write_table(array(), $zen_link);
+    write_table(array(), $zen_dbh);
 elseif (!$search)
-    write_table($_POST, $zen_link);
+    write_table($_POST, $zen_dbh);
 
 ?>
 
