@@ -11,16 +11,16 @@
 	include ("check_session.php");
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "access_levels";
-	$result = mysql_query($query, $bwb_link);
+	$result = $bwb_dbh->query($query);
 	
-	if (mysql_num_rows($result) < 1)
+	if ($result->rowCount() < 1)
 	{
 		echo "-no data-";
 		exit;
 	}
 
 	$row_delim = "";
-	while ($row = mysql_fetch_array($result))
+	while ($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
 		$table .= $row_delim . json_encode($row);
 		$row_delim = "@@@@@";
