@@ -19,15 +19,15 @@
 	$class = str_replace($search, $replace, $class);
 	
 	$query = "SELECT `description` FROM `" . BWB_TABLE_PREFIX . $class_table . "` WHERE `class`='" . $class . "'";
-	$result = mysql_query($query, $bwb_link);
+	$result = $bwb_dbh->query($query);
 	
-	if (mysql_num_rows($result) < 1)
+	if ($result->rowCount() < 1)
 	{
 		echo "-no data-";
 		exit;
 	}
 
-	$row = mysql_fetch_array($result);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	echo $row['description'];
 
 ?>
\ No newline at end of file
