@@ -23,10 +23,10 @@
 //	$query = "SELECT * FROM " . $css_table . " INNER JOIN " . $class_table . " ON " . $css_table . ".class = " . $class_table . ".class WHERE " . $css_table . ".class='" . $class . "'";
 //	echo $query;
 //	exit;
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 
-	if (mysql_num_rows($result) < 1)
+	if ($result->rowCount() < 1)
 		echo "-no data-";
 	else
 		print json_encode($row);
