@@ -20,16 +20,16 @@
 	$suffix = substr($menu, 4);
 	$menu_source  = "menu" . $suffix . "_items";
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_source . " ORDER BY sort_order";
-	$result = mysql_query($query, $bwb_link);
+	$result = $bwb_dbh->query($query);
 	
-	if (mysql_num_rows($result) < 1)
+	if ($result->rowCount() < 1)
 	{
 		echo "-no data-";
 		exit;
 	}
 
 	$row_delim = "";
-	while ($row = mysql_fetch_array($result))
+	while ($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
 //		$row['item_text'] = str_replace('AMPERSAND', '&', $row['item_text']);
 //		$row['item_text'] = str_replace('SEMICOLON', ';', $row['item_text']);
