@@ -4,6 +4,8 @@
 // Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 7/2/2012	ELL
+// Revised: 2/12/2013	ELL
+// Added paging of user tables.
 // 
 // 
 // 
@@ -11,24 +13,30 @@
 	include ("check_session.php");
 	
 	$user_table = $_POST['user_table'];
+	$page = $_POST['page'];
+	$max_rec = $_POST['max_rec'];
 	$_SESSION['last_user_table'] = $user_table;
 	
-	$query = "SELECT * FROM " . $user_table;
-	$result = mysql_query($query, $bwb_link);
+//	echo 100;
+//	exit;
 	
-	if (mysql_num_rows($result) < 1)
+	$start_row = $page * $max_rec;
+	$query = "SELECT * FROM " . $user_table . " LIMIT " . $start_row . "," . $max_rec;
+
+	$result = $bwb_dbh->query($query);
+	
+	if ($result->rowCount() < 1)
 	{
 		echo "-no data-";
 		exit;
 	}
 
 	$row_delim = "";
-	while ($row = mysql_fetch_array($result))
+	while ($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
 		$table .= $row_delim . json_encode($row);
 		$row_delim = "@@@@@";
 	}
 	
 	print $table;
-
 ?>
\ No newline at end of file
