@@ -12,7 +12,7 @@
 
 	$prune_page_bkup_days = $_REQUEST['prune_page_bkup_days'];
 	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_bkup WHERE DATE_SUB(CURDATE(),INTERVAL $prune_page_bkup_days DAY) > `revised`";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	header("Location: main.php?mode=admin");
 ?>
