@@ -39,12 +39,12 @@
 		
 		//Start by deleting all old data in table.
 		$query = "TRUNCATE TABLE " . BWB_TABLE_PREFIX . "site_css_preview";
-		$result = mysql_query($query, $bwb_link);
+		$cnt = $bwb_dbh->exec($query);
 		
 		//Get data from live table and move to preview table.
 		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . $css_table. "`";
-		$result = mysql_query($query, $bwb_link);
-		while ($row = mysql_fetch_array($result))
+		$result = $bwb_dbh->query($query);
+		while ($row = $result->fetch(PDO::FETCH_ASSOC))
 		{
 			$class = $row["class"];
 			$sub_class_of = $row["sub_class_of"];
@@ -154,7 +154,7 @@
 		$background_image, $background_attachment, $background_repeat, $background_position, $background_position_x, $background_position_y,
 		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout);
 		 
-		 	$result2 = mysql_query($query2, $bwb_link);
+		 	$cnt = $bwb_dbh->exec($query2);
 		} // end while
 	}
 	elseif ($submit == "Upload")
@@ -374,8 +374,8 @@
 	else $table_layout = "-not selected-";
 	
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '" . $class . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	
 		
 	if ($row_count > 0)
@@ -411,7 +411,7 @@
 		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout);
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 
 
 	/////////////////////////////////////////////
