@@ -33,10 +33,10 @@
 		$css_file = "menu_preview.css";
 		
 		$query = "TRUNCATE TABLE " . BWB_TABLE_PREFIX . $site_css_table . "menu_styles_preview";
-		$result = mysql_query($query, $bwb_link);
+		$cnt = $bwb_dbh->exec($query);
 		
 		$src_table = $menu . "_css";
-		copy_table(BWB_TABLE_PREFIX . $src_table, BWB_TABLE_PREFIX . "menu_styles_preview", $bwb_link, $bwb_database);
+		copy_table(BWB_TABLE_PREFIX . $src_table, BWB_TABLE_PREFIX . "menu_styles_preview", $bwb_dbh, $bwb_database);
 	}
 	else
 	{
@@ -232,8 +232,8 @@
 	else
 		$text_decoration_none = 0;
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.top_level_a" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, font='" . $top_level_font . "', font_size=" . $top_level_font_size
@@ -257,7 +257,7 @@
 		. ", shadow_y_offset=" . $top_level_shadow_y_offset . ", shadow_blur=" . $top_level_shadow_blur
 		. ", text_color='" . $top_level_text_color . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	///////////////////////////////////////////////////////////////////////////////////////////
 	if (($sub_level_1_underline == 0) && ($sub_level_1_overline == 0) && (sub_level_1_blink == 0))
@@ -265,8 +265,8 @@
 	else
 		$text_decoration_none = 0;
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.sub_level_1_a" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, font='" . $sub_level_1_font . "', font_size=" . $sub_level_1_font_size
@@ -290,7 +290,7 @@
 		. ", shadow_y_offset=" . $sub_level_1_shadow_y_offset . ", shadow_blur=" . $sub_level_1_shadow_blur
 		. ", text_color='" . $sub_level_1_text_color . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	///////////////////////////////////////////////////////////////////////////////////////////
 	if (($sub_level_2_underline == 0) && ($sub_level_2_overline == 0) && (sub_level_2_blink == 0))
@@ -298,8 +298,8 @@
 	else
 		$text_decoration_none = 0;
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.sub_level_2_a" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, font='" . $sub_level_2_font . "', font_size=" . $sub_level_2_font_size
@@ -323,12 +323,12 @@
 		. ", shadow_y_offset=" . $sub_level_2_shadow_y_offset . ", shadow_blur=" . $sub_level_2_shadow_blur
 		. ", text_color='" . $sub_level_2_text_color . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = 'ul.nav" . $suffix . ", .nav" . $suffix . " ul'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, border=" . $top_level_block_border_width . ", border_color='" . $top_level_block_border_color . "', border_sides=" . $top_level_block_border_sides
@@ -339,12 +339,12 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . ", .nav" . $suffix . " ul', use_table_data=1, border=" . $top_level_block_border_width
 		. ", border_color='" . $top_level_block_border_color . "', border_sides=" . $top_level_block_border_sides;
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = 'ul.nav" . $suffix . ">li'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, bkgd_color='" . $top_level_background_color 
@@ -357,12 +357,12 @@
 		. "', border=" . $top_level_item_border_width
 		. ", border_color='" . $top_level_item_border_color . "', border_sides=" . $top_level_item_border_sides . "', z_index=5";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = 'ul.nav" . $suffix . " li>ul'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -375,12 +375,12 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . " li>ul', use_table_data=1, border=" . $sub_level_block_border_width
 		. ", border_color='" . $sub_level_block_border_color . "', border_sides=" . $top_level_block_border_sides;
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.nav" . $suffix . " ul li a'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -393,12 +393,12 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.nav" . $suffix . " ul li a', use_table_data=1, border=" . $sub_level_item_border_width . ", border_color='"
 		. $sub_level_item_border_color . "', border_sides=" . $sub_level_item_border_sides;
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = 'ul.nav" . $suffix . " li:hover, .nav" . $suffix . " ul li a:hover'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -422,12 +422,12 @@
 		. "', border=" . $top_level_item_border_width . ", border_color='" . $top_level_item_border_color_hover
 		. "', border_sides=" . $top_level_item_border_sides . ", z_index=10";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = 'ul.nav" . $suffix . " li:active, .nav" . $suffix . " ul li a:active'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -444,12 +444,12 @@
 		. "', border=" . $top_level_item_border_width . ", border_color='" . $top_level_item_border_color_active
 		. "', border_sides=" . $top_level_item_border_sides;
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = 'ul.nav" . $suffix . ", .nav" . $suffix . " ul, .nav" . $suffix . " ul li a'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -462,13 +462,13 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . ", .nav" . $suffix . " ul, .nav" . $suffix . " ul li a', use_table_data=1, bkgd_color='"
 		. $sub_level_background_color . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
 //	$query = "SELECT `use_table_data` FROM " . $site_css_table . " WHERE `class` = '.nav" . $suffix . " a:hover'";
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.top_level_li" . $suffix . " A:hover'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -485,12 +485,12 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_li" . $suffix . " A:hover', use_table_data=1, text_color='"
 		. $top_level_text_color_hover . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////// new /////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.top_level_li" . $suffix . " A:visited:hover'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -503,12 +503,12 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_li" . $suffix . " A:visited:hover', use_table_data=1, text_color='"
 		. $top_level_text_color_hover . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.top_level_li" . $suffix . " A:visited'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -520,12 +520,12 @@
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_li" . $suffix . " A:visited', use_table_data=1, text_color='" . $top_level_text_color . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////// new //////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.sub_level_1_li" . $suffix . " A:hover'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -538,12 +538,12 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_1_li" . $suffix . " A:hover', use_table_data=1, text_color='"
 		. $sub_level_1_text_color_hover . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////// new //////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.sub_level_1_li" . $suffix . " A:visited:hover'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -556,12 +556,12 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_1_li" . $suffix . " A:visited:hover', use_table_data=1, text_color='"
 		. $sub_level_1_text_color_hover . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.sub_level_1_li" . $suffix . " A:visited'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -573,12 +573,12 @@
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_1_li" . $suffix . " A:visited', use_table_data=1, text_color='" . $sub_level_1_text_color . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////// new //////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.sub_level_2_li" . $suffix . " A:hover'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -591,12 +591,12 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_2_li" . $suffix . " A:hover', use_table_data=1, text_color='"
 		. $sub_level_2_text_color_hover . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////// new //////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.sub_level_2_li" . $suffix . " A:visited:hover'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -609,12 +609,12 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_2_li" . $suffix . " A:visited:hover', use_table_data=1, text_color='"
 		. $sub_level_2_text_color_hover . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.sub_level_2_li" . $suffix . " A:visited'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -626,12 +626,12 @@
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_2_li" . $suffix . " A:visited', use_table_data=1, text_color='" . $sub_level_2_text_color . "'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.top_level_li" . $suffix . " A'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
@@ -642,7 +642,7 @@
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_li" . $suffix . " A', use_table_data=1, display='block'";
 	}
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 
 
 	/////////////////////////////////////////////
