@@ -9,6 +9,8 @@
 // Added capability to handle multiple JavaScript Menus.
 // Revised: 2/10/2012	ELL
 // Added table prefix handling.  Added references to script folder configuration.
+// Revised: 2/10/2013	ELL
+// Fixed bug of underline being present even when not selected.
 	
 	include ("check_session.php");
 
@@ -24,7 +26,7 @@
 		$css_file = "menu_preview.css";
 		
 		$query = "TRUNCATE TABLE " . BWB_TABLE_PREFIX . "menu_styles_preview";
-		$result = mysql_query($query, $bwb_link);
+		$cnt = $bwb_dbh->exec($query);
 	}
 	else
 	{
@@ -215,8 +217,8 @@
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l0iout" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 		
 	if ($row_count > 0)
 	{
@@ -251,12 +253,12 @@
 		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l0iover" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 		
 	if ($row_count > 0)
 	{
@@ -291,12 +293,12 @@
 		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l0oout" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 		
 	if ($row_count > 0)
 	{
@@ -304,7 +306,7 @@
 		$condition = "`class` = '.m0l0oout" . $suffix . "'";
 		
 		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
-		0, 0, 0, 0, "-not selected-", 0, 0, 0, 0, "-not set-", 0,
+		0, 0, 0, 0, "-not selected-", 0, 0, $top_level_no_text_dec_out, 0, "-not set-", 0,
 		0, 0, -1, 0, "-not selected-", "-not selected-", $top_level_bkgd_color_out, $top_level_bkgd_opacity_out, $top_level_border_out, $top_level_border_color_out,
 		$top_level_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
 		0, -1000000, 0, 0, -1000000, 0, 0,
@@ -320,7 +322,7 @@
 		$insert_key = "class='.m0l0oout" . $suffix . "', ";
 		 
 		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
-		0, 0, 0, 0, "-not selected-", 0, 0, 0, 0, "-not set-", 0,
+		0, 0, 0, 0, "-not selected-", 0, 0, $top_level_no_text_dec_out, 0, "-not set-", 0,
 		0, 0, -1, 0, "-not selected-", "-not selected-", $top_level_bkgd_color_out, $top_level_bkgd_opacity_out, $top_level_border_out, $top_level_border_color_out,
 		$top_level_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
 		0, -1000000, 0, 0, -1000000, 0, 0,
@@ -331,12 +333,12 @@
 		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l0oover" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 		
 	if ($row_count > 0)
 	{
@@ -344,7 +346,7 @@
 		$condition = "`class` = '.m0l0oover" . $suffix . "'";
 		
 		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
-		0, 0, 0, 0, "-not selected-", 0, 0, 0, 0, "-not set-", 0,
+		0, 0, 0, 0, "-not selected-", 0, 0, $top_level_no_text_dec_over, 0, "-not set-", 0,
 		0, 0, -1, 0, "-not selected-", "-not selected-", $top_level_bkgd_color_over, -1, $top_level_border_over, $top_level_border_color_over,
 		$top_level_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
 		0, -1000000, 0, 0, -1000000, 0, 0,
@@ -360,7 +362,7 @@
 		$insert_key = "class='.m0l0oover" . $suffix . "', ";
 		 
 		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
-		0, 0, 0, 0, "-not selected-", 0, 0, 0, 0, "-not set-", 0,
+		0, 0, 0, 0, "-not selected-", 0, 0, $top_level_no_text_dec_over, 0, "-not set-", 0,
 		0, 0, -1, 0, "-not selected-", "-not selected-", $top_level_bkgd_color_over, -1, $top_level_border_over, $top_level_border_color_over,
 		$top_level_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
 		0, -1000000, 0, 0, -1000000, 0, 0,
@@ -371,13 +373,13 @@
 		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l1iout" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 		
 	if ($row_count > 0)
 	{
@@ -412,12 +414,12 @@
 		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l1iover" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 		
 	if ($row_count > 0)
 	{
@@ -452,12 +454,12 @@
 		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l1oout" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 		
 	if ($row_count > 0)
 	{
@@ -465,7 +467,7 @@
 		$condition = "`class` = '.m0l1oout" . $suffix . "'";
 		
 		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
-		0, 0, 0, 0, "-not selected-", 0, 0, 0, 0, "-not set-", 0,
+		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_1_no_text_dec_out, 0, "-not set-", 0,
 		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_1_bkgd_color_out, $sub_level_1_bkgd_opacity_out, $sub_level_1_border_out, $sub_level_1_border_color_out,
 		$sub_level_1_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
 		0, -1000000, 0, 0, -1000000, 0, 0,
@@ -481,7 +483,7 @@
 		$insert_key = "class='.m0l1oout" . $suffix . "', ";
 		 
 		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
-		0, 0, 0, 0, "-not selected-", 0, 0, 0, 0, "-not set-", 0,
+		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_1_no_text_dec_out, 0, "-not set-", 0,
 		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_1_bkgd_color_out, $sub_level_1_bkgd_opacity_out, $sub_level_1_border_out, $sub_level_1_border_color_out,
 		$sub_level_1_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
 		0, -1000000, 0, 0, -1000000, 0, 0,
@@ -492,12 +494,12 @@
 		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l1oover" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 		
 	if ($row_count > 0)
 	{
@@ -505,7 +507,7 @@
 		$condition = "`class` = '.m0l1oover" . $suffix . "'";
 		
 		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
-		0, 0, 0, 0, "-not selected-", 0, 0, 0, 0, "-not set-", 0,
+		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_1_no_text_dec_over, 0, "-not set-", 0,
 		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_1_bkgd_color_over, -1, $sub_level_1_border_over, $sub_level_1_border_color_over,
 		$sub_level_1_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
 		0, -1000000, 0, 0, -1000000, 0, 0,
@@ -521,7 +523,7 @@
 		$insert_key = "class='.m0l1oover" . $suffix . "', ";
 		 
 		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
-		0, 0, 0, 0, "-not selected-", 0, 0, 0, 0, "-not set-", 0,
+		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_1_no_text_dec_over, 0, "-not set-", 0,
 		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_1_bkgd_color_over, -1, $sub_level_1_border_over, $sub_level_1_border_color_over,
 		$sub_level_1_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
 		0, -1000000, 0, 0, -1000000, 0, 0,
@@ -532,13 +534,13 @@
 		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l2iout" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 		
 	if ($row_count > 0)
 	{
@@ -573,12 +575,12 @@
 		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l2iover" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 		
 	if ($row_count > 0)
 	{
@@ -613,12 +615,12 @@
 		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l2oout" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 		
 	if ($row_count > 0)
 	{
@@ -626,7 +628,7 @@
 		$condition = "`class` = '.m0l2oout" . $suffix . "'";
 		
 		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
-		0, 0, 0, 0, "-not selected-", 0, 0, 0, 0, "-not set-", 0,
+		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_2_no_text_dec_out, 0, "-not set-", 0,
 		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_2_bkgd_color_out, $sub_level_2_bkgd_opacity_out, $sub_level_2_border_out, $sub_level_2_border_color_out,
 		$sub_level_2_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
 		0, -1000000, 0, 0, -1000000, 0, 0,
@@ -642,7 +644,7 @@
 		$insert_key = "class='.m0l2oout" . $suffix . "', ";
 		 
 		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
-		0, 0, 0, 0, "-not selected-", 0, 0, 0, 0, "-not set-", 0,
+		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_2_no_text_dec_out, 0, "-not set-", 0,
 		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_2_bkgd_color_out, $sub_level_2_bkgd_opacity_out, $sub_level_2_border_out, $sub_level_2_border_color_out,
 		$sub_level_2_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
 		0, -1000000, 0, 0, -1000000, 0, 0,
@@ -653,12 +655,12 @@
 		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l2oover" . $suffix . "'";
-	$result = mysql_query($query, $bwb_link);
-	$row_count = mysql_num_rows($result);
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
 		
 	if ($row_count > 0)
 	{
@@ -666,7 +668,7 @@
 		$condition = "`class` = '.m0l2oover" . $suffix . "'";
 		
 		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
-		0, 0, 0, 0, "-not selected-", 0, 0, 0, 0, "-not set-", 0,
+		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_2_no_text_dec_over, 0, "-not set-", 0,
 		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_2_bkgd_color_over, -1, $sub_level_2_border_over, $sub_level_2_border_color_over,
 		$sub_level_2_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
 		0, -1000000, 0, 0, -1000000, 0, 0,
@@ -682,7 +684,7 @@
 		$insert_key = "class='.m0l2oover" . $suffix . "', ";
 		 
 		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
-		0, 0, 0, 0, "-not selected-", 0, 0, 0, 0, "-not set-", 0,
+		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_2_no_text_dec_over, 0, "-not set-", 0,
 		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_2_bkgd_color_over, -1, $sub_level_2_border_over, $sub_level_2_border_color_over,
 		$sub_level_2_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
 		0, -1000000, 0, 0, -1000000, 0, 0,
@@ -693,7 +695,7 @@
 		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
 	}
 //	echo $query;
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	/////////////////////////////////////////////
 	// Build string for menu.css file /////
