@@ -14,12 +14,12 @@
 
 
 	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "page_titles` WHERE `page_name` = '" . $page_name . "'";
-	$result = mysql_query($query, $bwb_link);
-	if (mysql_fetch_array($result))
+	$result = $bwb_dbh->query($query);
+	if ($result->fetch(PDO::FETCH_ASSOC))
 		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_titles SET `title`='$title' WHERE `page_name`='$page_name'";
 	else
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_titles (`page_name`, `title`) VALUES ('$page_name', '$title')";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	if ($page_name == "_default_")
 		header("Location: main.php?mode=title");
