@@ -12,8 +12,8 @@
 
 	
 	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data";
-	$result = mysql_query($query, $bwb_link);
-	while($row = mysql_fetch_array($result))
+	$result = $bwb_dbh->query($query);
+	while($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
 		$page_name = $row["page_name"];
 		if (isset($_POST[$page_name]))
@@ -22,7 +22,7 @@
 			$restricted = 0;
 			
 		$query2 = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET restricted = $restricted WHERE page_name = '$page_name'";
-		$result2 = mysql_query($query2, $bwb_link);
+		$cnt = $bwb_dbh->exec($query2);
 	}
 	
 	header("Location: restrict_editing_access.php");
