@@ -20,7 +20,7 @@
 	$class = str_replace($search, $replace, $class);
 	
 	$query = "UPDATE `" . BWB_TABLE_PREFIX . $class_table . "` SET `description`='" . $description. "' WHERE `class`='" . $class . "'";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	if (!$result)
 		echo "-no data-";
