@@ -16,7 +16,7 @@
 	if (($menu_name != "") && isset($menu_name))
 	{	
 		$query = "UPDATE `" . BWB_TABLE_PREFIX . "menus` SET `description` = '$description' WHERE `menu_name` = '$menu_name'";
-		$result = mysql_query($query, $bwb_link);
+		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	header("Location: manage_menu.php?menu=$menu_name");
