@@ -21,7 +21,7 @@
 	$login_page = $_POST["login_page"];
 		
 	$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET login_required=" . $login_required . ", user_table='" . $user_table . "', AccessLevel='" . $access_level . "', login_page='" . $login_page . "' WHERE page_name='" . $page_name . "'";
-	$result = mysql_query($query, $bwb_link);
+	$cnt = $bwb_dbh->exec($query);
 	
 	echo "Update complete";
 
