@@ -7,16 +7,16 @@
 //	Revised: 2/10/2012	ELL
 //  Added table prefix handling.
 	
-	define('VERSION', "3.6.05");
-	define('VER_DATE',  "25 dec 2012 01:00:00");	// Release date of this version.
-	define('LAST_VER_DATE',  "16 dec 2012 01:00:00");	// Release date of last version.
+	define('VERSION', "4.0.01");
+	define('VER_DATE',  "16 mar 2013 01:00:00");	// Release date of this version.
+	define('LAST_VER_DATE',  "24 feb 2013 01:00:00");	// Release date of last version.
 	
 	include ("../connect/db_connection.php");
 	include ("../connect/config.php");
 	
 	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "version`";
-	$result = mysql_query($query, $bwb_link);
-	$row = mysql_fetch_array($result);
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$version = $row["version"];
 	
 	if (VERSION == $version)
@@ -24,8 +24,8 @@
 	else
 	{
 		echo "<script language='JavaScript'  type='text/javascript'>\n";
-		echo "document.getElementById('version').style.top='5px'\n";
-		echo "document.getElementById('version').style.left='350px'\n";
+		echo "document.getElementById('bwb_version').style.top='5px'\n";
+		echo "document.getElementById('bwb_version').style.left='350px'\n";
 		echo "</script>\n";
 		echo "<span style='color:#F00;'>\n";
 		echo "Your database-revision-patch level does not match your program-files-revision level.  Please contact your system administrator.<br>\n";
